@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2010 Sebastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2024 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -14,17 +14,20 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat.  If not, see <https://www.gnu.org/licenses/>.
  */
 
-#ifndef __WEECHAT_GUI_MAIN_H
-#define __WEECHAT_GUI_MAIN_H 1
+#ifndef WEECHAT_GUI_MAIN_H
+#define WEECHAT_GUI_MAIN_H
 
 /* main functions (GUI dependent) */
 
-extern void gui_main_loop ();
-extern void gui_main_pre_init (int *argc, char **argv[]);
-extern void gui_main_init ();
+extern void gui_main_get_password (const char **prompt,
+                                   char *password, int size);
+extern void gui_main_debug_libs ();
 extern void gui_main_end (int clean_exit);
 
-#endif /* __WEECHAT_GUI_MAIN_H */
+/* terminal functions (GUI dependent) */
+extern void gui_term_set_eat_newline_glitch (int value);
+
+#endif /* WEECHAT_GUI_MAIN_H */
