@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2010 Sebastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2024 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -14,20 +14,12 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat.  If not, see <https://www.gnu.org/licenses/>.
  */
 
-#ifndef __WEECHAT_LOGGER_TAIL_H
-#define __WEECHAT_LOGGER_TAIL_H 1
+#ifndef WEECHAT_PLUGIN_LOGGER_TAIL_H
+#define WEECHAT_PLUGIN_LOGGER_TAIL_H
 
-struct t_logger_line
-{
-    char *data;                        /* line content                      */
-    struct t_logger_line *next_line;   /* link to next line                 */
-};
+extern struct t_arraylist *logger_tail_file (const char *filename, int lines);
 
-extern struct t_logger_line *logger_tail_file (const char *filename,
-                                               int n_lines);
-extern void logger_tail_free (struct t_logger_line *lines);
-
-#endif /* __WEECHAT_LOGGER_TAIL_H */
+#endif /* WEECHAT_PLUGIN_LOGGER_TAIL_H */
